@@ -11,7 +11,7 @@ TODO:
 
 """
 
-import logging, traceback, re, lxml, isodate
+import logging, traceback, re, isodate
 
 from unify import lookup_party_identifiers
 
@@ -609,7 +609,7 @@ def check_x509_data_content(anchorid, rootcert, anchor_certid, cpp):
         namespaces=_NSMAP)[0]
     return check_x509_data_content_2(anchorid, rootcert, anchor_certid, anchor_cert)
 
-def check_x509_data_content_2(rootcert, anchor_certid, anchor_cert):
+def check_x509_data_content_2(anchorid, rootcert, anchor_certid, anchor_cert):
     anchor_cert_data = anchor_cert.xpath(
         'descendant::ds:X509Certificate/text()',
         namespaces=_NSMAP)[0]
