@@ -9,7 +9,7 @@ A ChannelProfileHandler class
 
 from lxml import etree
 from copy import deepcopy
-import logging, os
+import logging
 from schema import cppa3_content_model as cppa3_content_model
 
 logging.basicConfig(level=logging.DEBUG)
@@ -185,7 +185,6 @@ def apply_default_to_complex_subelement(element, default):
         logging.info('{} not in content model, taken from input'.format(tag))
         return element
     else:
-        model = cppa3_content_model[tag]
         element_children = list(element)
         default_children = list(default)
         if len(element_children) == 0:
