@@ -84,6 +84,9 @@ cppa3_content_model = {
                             cppa('Splitting'),
                             cppa('AlternateChannel')],
 
+    cppa('AMQPChannel') : [cppa('Description'),
+                           cppa('AMQPSecurity')],
+
     cppa('PullHandling') : [cppa('PullChannelId')],
 
     cppa('Compression') : [cppa('CompressionAlgorithm')],
@@ -118,6 +121,7 @@ cppa3_content_model = {
                           cppa('CanonicalizationMethod'),
                           cppa('SignatureTransformation'),
                           cppa('SigningCertificateRef'),
+                          cppa('SigningCertificateRequired'),
                           cppa('SigningCertificateRefType'),
                           cppa('SigningTrustAnchorSetRef'),
                           cppa('SigningCertificatePolicySetRef'),
@@ -127,8 +131,14 @@ cppa3_content_model = {
                           cppa('SignExternalPayloads')],
 
     cppa('Encryption') : [ cppa('KeyEncryption'),
-                           cppa('DataEncryption'),
+
+                           cppa('EncryptionAlgorithm'),
+                           cppa('EncryptElements'),
+                           cppa('EncryptAttachments'),
+                           cppa('EncryptExternalPayloads'),
+
                            cppa('EncryptionCertificateRef'),
+                           cppa('EncryptionCertificateRequired'),
                            cppa('EncryptionCertificateRefType'),
                            cppa('EncryptionTrustAnchorSetRef'),
                            cppa('EncryptionCertificatePolicySetRef')],
@@ -138,10 +148,10 @@ cppa3_content_model = {
                               cppa('DigestAlgorithm')],
 
 
-    cppa('DataEncryption') : [ cppa('EncryptionAlgorithm'),
-                               cppa('EncryptElements'),
-                               cppa('EncryptAttachments'),
-                               cppa('EncryptExternalPayloads')],
+    #cppa('DataEncryption') : [ cppa('EncryptionAlgorithm'),
+    #                           cppa('EncryptElements'),
+    #                           cppa('EncryptAttachments'),
+    #                           cppa('EncryptExternalPayloads')],
 
     cppa('ErrorHandling') : [ cppa('DeliveryFailuresNotifyProducer'),
                               cppa('ProcessErrorNotifyConsumer'),
