@@ -58,6 +58,22 @@ class MatchTestCase( unittest.TestCase ):
     def test_0009(self):
        self.do_reverse_match('0009')
 
+    def test_0090(self):
+       self.do_reverse_match('0090')
+
+    def test_0091(self):
+       self.do_reverse_match('0091')
+
+    def test_0120(self):
+       self.do_reverse_match('0120')
+
+    def test_0121(self):
+       self.do_reverse_match('0121')
+
+    def test_0122(self):
+       self.do_reverse_match('0122')
+
+
     def test_0060(self):
        self.do_reverse_match('0060')
 
