@@ -92,10 +92,8 @@ class ProfileTestCase( unittest.TestCase ):
     <cppa:WSSecurityBinding>
       <cppa:WSSVersion>1.1</cppa:WSSVersion>
       <cppa:Encryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#aes128-cbc</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#aes128-cbc</cppa:EncryptionAlgorithm>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
   </cppa:ebMS3Channel>
@@ -112,9 +110,7 @@ class ProfileTestCase( unittest.TestCase ):
             <cppa:WSSecurityBinding pycppa3:ifused="true">
                 <cppa:WSSVersion>1.1</cppa:WSSVersion>
             <cppa:Encryption>
-                    <cppa:DataEncryption>
-                        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-                    </cppa:DataEncryption>
+                     <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
                 </cppa:Encryption>
             </cppa:WSSecurityBinding>
         </cppa:ebMS3Channel></cppa:CPP>
@@ -129,9 +125,7 @@ class ProfileTestCase( unittest.TestCase ):
     <cppa:WSSecurityBinding>
       <cppa:WSSVersion>1.1</cppa:WSSVersion>
       <cppa:Encryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
   </cppa:ebMS3Channel>
@@ -148,9 +142,7 @@ class ProfileTestCase( unittest.TestCase ):
             <cppa:WSSecurityBinding>
                 <cppa:WSSVersion>1.1</cppa:WSSVersion>
             <cppa:Encryption>
-                    <cppa:DataEncryption>
-                        <cppa:EncryptAttachments>true</cppa:EncryptAttachments>
-                    </cppa:DataEncryption>
+                    <cppa:EncryptAttachments>true</cppa:EncryptAttachments>
                 </cppa:Encryption>
             </cppa:WSSecurityBinding>
         </cppa:ebMS3Channel></cppa:CPP>
@@ -165,11 +157,9 @@ class ProfileTestCase( unittest.TestCase ):
     <cppa:WSSecurityBinding>
       <cppa:WSSVersion>1.1</cppa:WSSVersion>
       <cppa:Encryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#aes128-cbc</cppa:EncryptionAlgorithm>
-          <cppa:EncryptAttachments>true</cppa:EncryptAttachments>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#aes128-cbc</cppa:EncryptionAlgorithm>
+        <cppa:EncryptAttachments>true</cppa:EncryptAttachments>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
   </cppa:ebMS3Channel>
@@ -187,10 +177,8 @@ class ProfileTestCase( unittest.TestCase ):
             <cppa:WSSecurityBinding pycppa3:ifused="true">
                 <cppa:WSSVersion>1.1</cppa:WSSVersion>
             <cppa:Encryption>
-                    <cppa:DataEncryption>
-                        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-                        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes256-gcm</cppa:EncryptionAlgorithm>
-                    </cppa:DataEncryption>
+                      <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
+                      <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes256-gcm</cppa:EncryptionAlgorithm>
                 </cppa:Encryption>
             </cppa:WSSecurityBinding>
         </cppa:ebMS3Channel></cppa:CPP>
@@ -205,10 +193,8 @@ class ProfileTestCase( unittest.TestCase ):
     <cppa:WSSecurityBinding>
       <cppa:WSSVersion>1.1</cppa:WSSVersion>
       <cppa:Encryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes256-gcm</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes256-gcm</cppa:EncryptionAlgorithm>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
   </cppa:ebMS3Channel>
@@ -259,9 +245,7 @@ class ProfileTestCase( unittest.TestCase ):
           <cppa:MaskGenerationFunction>http://www.w3.org/2009/xmlenc11#mgf1sha256</cppa:MaskGenerationFunction>
           <cppa:DigestAlgorithm>http://www.w3.org/2001/04/xmlenc#sha256</cppa:DigestAlgorithm>
         </cppa:KeyEncryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
         <cppa:EncryptionCertificateRef certId="_YE5XZF"/>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
@@ -329,9 +313,7 @@ class ProfileTestCase( unittest.TestCase ):
           <cppa:MaskGenerationFunction>http://www.w3.org/2009/xmlenc11#mgf1sha256</cppa:MaskGenerationFunction>
           <cppa:DigestAlgorithm>http://www.w3.org/2001/04/xmlenc#sha256</cppa:DigestAlgorithm>
         </cppa:KeyEncryption>
-        <cppa:DataEncryption>
-          <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
-        </cppa:DataEncryption>
+        <cppa:EncryptionAlgorithm>http://www.w3.org/2009/xmlenc11#aes128-gcm</cppa:EncryptionAlgorithm>
         <cppa:EncryptionCertificateRef certId="_YE5XZF"/>
       </cppa:Encryption>
     </cppa:WSSecurityBinding>
@@ -1258,9 +1240,7 @@ class ProfileTestCase( unittest.TestCase ):
       <cppa:SigningCertificateRef certId="_SCNXER"/>
     </cppa:Signature>
     <cppa:Encryption>
-      <cppa:DataEncryption>
-        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
-      </cppa:DataEncryption>
+      <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
     </cppa:Encryption>
     <cppa:ErrorHandling>
       <cppa:ReceiverErrorsReportChannelId>b_ch_send_signals</cppa:ReceiverErrorsReportChannelId>
@@ -1284,9 +1264,7 @@ class ProfileTestCase( unittest.TestCase ):
       <cppa:SignatureAlgorithm>http://www.w3.org/2000/09/xmldsig#rsa-sha1</cppa:SignatureAlgorithm>
     </cppa:Signature>
     <cppa:Encryption>
-      <cppa:DataEncryption>
-        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
-      </cppa:DataEncryption>
+      <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
       <cppa:EncryptionCertificateRef certId="_4UP74O"/>
     </cppa:Encryption>
     <cppa:ErrorHandling>
@@ -1478,9 +1456,7 @@ class ProfileTestCase( unittest.TestCase ):
       <cppa:SigningCertificateRef certId="_OYHRBO"/>
     </cppa:Signature>
     <cppa:Encryption>
-      <cppa:DataEncryption>
-        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
-      </cppa:DataEncryption>
+      <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
     </cppa:Encryption>
     <cppa:ErrorHandling>
       <cppa:ReceiverErrorsReportChannelId>easeegas_as2_signal_inbound</cppa:ReceiverErrorsReportChannelId>
@@ -1504,9 +1480,7 @@ class ProfileTestCase( unittest.TestCase ):
       <cppa:SignatureAlgorithm>http://www.w3.org/2000/09/xmldsig#rsa-sha1</cppa:SignatureAlgorithm>
     </cppa:Signature>
     <cppa:Encryption>
-      <cppa:DataEncryption>
-        <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
-      </cppa:DataEncryption>
+      <cppa:EncryptionAlgorithm>http://www.w3.org/2001/04/xmlenc#tripledes-cbc</cppa:EncryptionAlgorithm>
       <cppa:EncryptionCertificateRef certId="_YE5XZF"/>
     </cppa:Encryption>
     <cppa:ErrorHandling>
